%if 0%{?el7}
%define dist .el7
%endif

# This package builds a daemon-application,
# thus we build with fully hardening.
%global _hardened_build 1

# Systemd or SysV?
%if 0%{?fedora} >= 18 || 0%{?rhel} >= 7
%global with_systemd 1
%endif # 0%{?fedora} >= 18 || 0%{?rhel} >= 7

# Setup _pkgdocdir if not defined already.
%{!?_pkgdocdir:%global _pkgdocdir	%{_docdir}/%{name}-%{version}}

Name:			icecast
Version:		2.4.4
Release:		1%{?dist}
Summary:		ShoutCast compatible streaming media server
%{?el5:Group:		Applications/Multimedia}

License:		GPLv2+
URL:			http://www.icecast.org/
Source0:		http://downloads.xiph.org/releases/%{name}/%{name}-%{version}.tar.gz
Source1:		%{name}.init
Source2:		%{name}.logrotate
Source3:		%{name}.service
Source4:		%{name}.xml
Source5:		status3.xsl

%{?el5:BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)}
BuildRequires:		automake
BuildRequires:		curl-devel >= 7.10.0
BuildRequires:		libogg-devel >= 1.0
BuildRequires:		libtheora-devel >= 1.0
BuildRequires:		libvorbis-devel >= 1.0
BuildRequires:		libxml2-devel
BuildRequires:		libxslt-devel
BuildRequires:		openssl-devel
BuildRequires:		speex-devel
BuildRequires:		gcc

Requires(pre):		/usr/sbin/useradd
Requires(postun):	/usr/sbin/userdel

%if 0%{?with_systemd}
BuildRequires:		systemd-units

Requires(post):		systemd-sysv
Requires(post):		systemd-units
Requires(preun):	systemd-units
Requires(postun):	systemd-units
%else # 0%{?with_systemd}
Requires(post):		/sbin/chkconfig
Requires(preun):	/sbin/chkconfig
Requires(preun):	/sbin/service
Requires(postun):	/sbin/service
%endif # 0%{?with_systemd}

Provides:		streaming-server

%description
Icecast is a streaming media server which currently supports
Ogg Vorbis and MP3 audio streams.  It can be used to create an
Internet radio station or a privately running jukebox and many
things in between.  It is very versatile in that new formats
can be added relatively easily and supports open standards for
communication and interaction.


%package doc
Summary:		Documentation files for %{name}
%{?el5:Group:		Documentation}
%{!?el5:BuildArch:	noarch}

%description doc
This package contains the documentation files for %{name}.


%prep
%setup -q
find doc/ -type f | xargs chmod 0644
%{__cp} -a doc/ html/
find html/ -name 'Makefile*' | xargs %{__rm} -f


%build
%configure		\
	--with-curl	\
	--with-openssl	\
	--with-ogg	\
	--with-theora	\
	--with-speex
%{__make} %{?_smp_mflags}


%install
%{?el5:%{__rm} -rf %{buildroot}}
%{__make} install DESTDIR=%{buildroot}
%{__rm} -rf %{buildroot}%{_datadir}/%{name}/doc
%{__rm} -rf %{buildroot}%{_docdir}/%{name}
%if 0%{?with_systemd}
%{__install} -D -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}.service
%else # 0%{?with_systemd}
%{__install} -D -m 0755 %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%endif # 0%{?with_systemd}
%{__install} -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
%{__install} -D -m 0640 %{SOURCE4} %{buildroot}%{_sysconfdir}/%{name}.xml
%{__install} -D -m 0644 %{SOURCE5} %{buildroot}%{_datadir}/%{name}/web/status3.xsl
%{__mkdir} -p %{buildroot}%{_localstatedir}/log/%{name}	\
	%{buildroot}%{_localstatedir}/run/%{name}	\
	%{buildroot}%{_pkgdocdir}/{conf,examples}
%{__cp} -a html/ AUTHORS ChangeLog COPYING NEWS TODO %{buildroot}%{_pkgdocdir}
%{__cp} -a conf/*.dist %{buildroot}%{_pkgdocdir}/conf
%{__cp} -a examples/%{name}_auth-1.0.tar.gz %{buildroot}%{_pkgdocdir}/examples


%{?el5:%clean}
%{?el5:%{__rm} -rf %{buildroot}}


%pre
/usr/sbin/useradd -M -r -d /usr/share/%{name} -s /sbin/nologin \
	-c "%{name} streaming server" %{name} > /dev/null 2>&1 || :

%post
%if 0%{?with_systemd}
%systemd_post %{name}.service
%else # 0%{?with_systemd}
/sbin/chkconfig --add %{name}
%endif # 0%{?with_systemd}

%preun
%if 0%{?with_systemd}
%systemd_preun %{name}.service
%else # 0%{?with_systemd}
if [ $1 = 0 ]; then
	/sbin/service %{name} stop >/dev/null 2>&1
	/sbin/chkconfig --del %{name}
fi
%endif # 0%{?with_systemd}

%postun
%if 0%{?with_systemd}
%systemd_postun_with_restart %{name}.service
%else # 0%{?with_systemd}
if [ "$1" -ge "1" ]; then
	/sbin/service %{name} condrestart >/dev/null 2>&1
fi
%endif # 0%{?with_systemd}
if [ $1 = 0 ] ; then
	/usr/sbin/userdel %{name} >/dev/null 2>&1 || :
fi

%if 0%{?with_systemd}
%triggerun -- %{name} < 2.3.2-7
# Save the current service runlevel info
/usr/bin/systemd-sysv-convert --save %{name} >/dev/null 2>&1 ||:
# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del %{name} >/dev/null 2>&1 || :
/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
%endif # 0%{?with_systemd}


%files
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}.xml
%dir %attr(-,%{name},%{name}) %{_localstatedir}/log/%{name}
%doc %dir %{_pkgdocdir}
%doc %{_pkgdocdir}/COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_sysconfdir}/logrotate.d/%{name}
%if 0%{?with_systemd}
%{_unitdir}/%{name}.service
%else # 0%{?with_systemd}
%dir %attr(-,%{name},%{name}) %{_localstatedir}/run/%{name}
%{_initrddir}/%{name}
%endif # 0%{?with_systemd}

%files doc
%doc %{_pkgdocdir}


%changelog
* Sat Nov 24 2018 momo-i <webmaster@momo-i.org> - 2.4.4-1
- Update to 2.4.4

* Tue May 10 2016 momo-i <webmaster@momo-i.org> - 2.4.3-1
- Update to 2.4.3

* Thu Sep 03 2015 momo-i <webmaster@momo-i.org> - 2.4.2-3
- Update dist for centos7

* Mon Aug 10 2015 momo-i <webmaster@momo-i.org> - 2.4.2-2
- Rebuilt for fc23

* Thu Jul 09 2015 momo-i <webmaster@momo-i.org> - 2.4.2-1
- Update to 2.4.2
